============
Installation
============

At the command line::

    $ pip install baremetal-network-provisioning

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv baremetal-network-provisioning
    $ pip install baremetal-network-provisioning
